==> react-native-hotqa-sdk-0.0.22.tgz: package/src/components/count-down/index.js <==
import React, {useEffect} from 'react';
import {StyleSheet, View, Text, Alert} from 'react-native';

export default (props) => {
  const {hours = 0, minutes = 0, seconds = 0, endTime} = props;
  const [paused, setPaused] = React.useState(false);
  const [over, setOver] = React.useState(false);
  const [time, setTime] = React.useState({
    hours: parseInt(hours),
    minutes: parseInt(minutes),
    seconds: parseInt(seconds),
  });

  const tick = () => {
    if (paused || over) {
      return;
    }
    if (time.hours === 0 && time.minutes === 0 && time.seconds === 0) {
      endTime();
      setOver(true);
    } else if (time.minutes === 0 && time.seconds === 0) {
      setTime({
        hours: time.hours - 1,
        minutes: 59,
        seconds: 59,
      });
    } else if (time.seconds === 0) {
      setTime({
        hours: time.hours,
        minutes: time.minutes - 1,
        seconds: 59,
      });
    } else {
      setTime({
        hours: time.hours,
        minutes: time.minutes,
        seconds: time.seconds - 1,
      });
    }
  };

  const reset = () => {
    setTime({
      hours: parseInt(hours),
      minutes: parseInt(minutes),
      seconds: parseInt(seconds),
    });
    setPaused(false);
    setOver(false);
  };

  useEffect(() => {
    let timerID = setInterval(() => tick(), 1000);
    return () => clearInterval(timerID);
  });

  return (
    <View style={styles.content}>
      <Text style={styles.title}>{`${time.hours
        .toString()
        .padStart(2, '0')}:${time.minutes
        .toString()
        .padStart(2, '0')}:${time.seconds.toString().padStart(2, '0')}`}</Text>
      {/* <Text>{over ? "Time's up!" : ''}</Text> */}
    </View>
  );
};
const styles = StyleSheet.create({
  content: {
    width: '50%',
    backgroundColor: 'tomato',
    alignItems: 'center',
    justifyContent: 'center',
    borderRadius: 15,
  },
  title: {
    color: 'white',
    fontSize: 16,
    padding: 6,
    fontWeight: 'bold',
  },
});

==> react-native-hotqa-sdk-0.1.1.tgz: package/src/components/count-down/index.js <==
import React, {useEffect} from 'react';
import {StyleSheet, View, Text, Alert} from 'react-native';

export default (props) => {
  const {hours = 0, minutes = 0, seconds = 0, endTime} = props;
  const [paused, setPaused] = React.useState(false);
  const [over, setOver] = React.useState(false);
  const [time, setTime] = React.useState({
    hours: parseInt(hours),
    minutes: parseInt(minutes),
    seconds: parseInt(seconds),
  });

  const tick = () => {
    if (paused || over) {
      return;
    }
    if (time.hours === 0 && time.minutes === 0 && time.seconds === 0) {
      endTime();
      setOver(true);
    } else if (time.minutes === 0 && time.seconds === 0) {
      setTime({
        hours: time.hours - 1,
        minutes: 59,
        seconds: 59,
      });
    } else if (time.seconds === 0) {
      setTime({
        hours: time.hours,
        minutes: time.minutes - 1,
        seconds: 59,
      });
    } else {
      setTime({
        hours: time.hours,
        minutes: time.minutes,
        seconds: time.seconds - 1,
      });
    }
  };

  const reset = () => {
    setTime({
      hours: parseInt(hours),
      minutes: parseInt(minutes),
      seconds: parseInt(seconds),
    });
    setPaused(false);
    setOver(false);
  };

  useEffect(() => {
    let timerID = setInterval(() => tick(), 1000);
    return () => clearInterval(timerID);
  });

  return (
    <View style={styles.content}>
      <Text style={styles.title}>{`${time.hours
        .toString()
        .padStart(2, '0')} : ${time.minutes
        .toString()
        .padStart(2, '0')} : ${time.seconds
        .toString()
        .padStart(2, '0')}`}</Text>
      {/* <Text>{over ? "Time's up!" : ''}</Text> */}
    </View>
  );
};
const styles = StyleSheet.create({
  content: {
    // width: '100%',
    // backgroundColor: 'tomato',
    alignItems: 'center',
    justifyContent: 'center',
    // borderRadius: 15,
  },
  title: {
    color: 'white',
    fontSize: 20,
    // padding: 6,
    // fontWeight: 'bold',
  },
});
